@@ -1,7 +1,7 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab:
 /*
 Gwenview: an image viewer
-Copyright 2008 Aurélien Gâteau <aurelien.gateau@free.fr>
+Copyright 2008 Aurélien Gâteau <agateau@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -215,13 +215,6 @@ struct PreviewItemDelegatePrivate {
 		// Necessary otherwise we won't see the save button itself
 		mSaveButton->adjustSize();
 
-		// This is hackish.
-		// Show/hide the frame to make sure mSaveButton->render produces
-		// something coherent.
-		mSaveButton->show();
-		mSaveButton->repaint();
-		mSaveButton->hide();
-
 		mSaveButtonPixmap = QPixmap(mSaveButton->sizeHint());
 		mSaveButtonPixmap.fill(Qt::transparent);
 		mSaveButton->render(&mSaveButtonPixmap, QPoint(), QRegion(), QWidget::DrawChildren);
@@ -248,14 +241,18 @@ struct PreviewItemDelegatePrivate {
 
 	bool hoverEventFilter(QHoverEvent* event) {
 		QModelIndex index = mView->indexAt(event->pos());
-		if (mIndexUnderCursor.isValid()) {
-			// Always repaint in case we are over the rating row
+		if (index != mIndexUnderCursor) {
+			updateHoverUi(index);
+		} else {
+			// Same index, nothing to do, but repaint anyway in case we are
+			// over the rating row
 			mView->update(mIndexUnderCursor);
 		}
-		if (index == mIndexUnderCursor) {
-			// Same index, nothing to do
-			return false;
-		}
+		return false;
+	}
+
+
+	void updateHoverUi(const QModelIndex& index) {
 		QModelIndex oldIndex = mIndexUnderCursor;
 		mIndexUnderCursor = index;
 		mView->update(oldIndex);
@@ -285,7 +282,6 @@ struct PreviewItemDelegatePrivate {
 			mSaveButton->hide();
 			mTipLabel->hide();
 		}
-		return false;
 	}
 
 	QRect ratingRectFromIndexRect(const QRect& rect) const {
@@ -469,6 +465,7 @@ struct PreviewItemDelegatePrivate {
 			textList << text;
 		}
 		if (!elided) {
+			mTipLabel->hide();
 			return;
 		}
 		mTipLabel->setText(textList.join("\n"));
@@ -547,6 +544,11 @@ PreviewItemDelegate::PreviewItemDelegate(ThumbnailView* view)
 	d->mThumbnailSize = view->thumbnailSize();
 	d->mDetails = FileNameDetail;
 
+	connect(view, SIGNAL(rowsRemovedSignal(const QModelIndex&, int, int)),
+		SLOT(slotRowsChanged()));
+	connect(view, SIGNAL(rowsInsertedSignal(const QModelIndex&, int, int)),
+		SLOT(slotRowsChanged()));
+
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
 	d->mRatingPainter.setAlignment(Qt::AlignHCenter | Qt::AlignBottom);
 	d->mRatingPainter.setLayoutDirection(view->layoutDirection());
@@ -660,12 +662,7 @@ void PreviewItemDelegate::paint( QPainter * painter, const QStyleOptionViewItem
 		borderColor = bgColor.dark(SELECTION_BORDER_DARKNESS);
 	} else {
 		bgColor = viewport->palette().color(viewport->backgroundRole());
-
-		if (bgColor.value() < 128) {
-			borderColor = bgColor.dark(200);
-		} else {
-			borderColor = bgColor.light(200);
-		}
+		borderColor = bgColor.light(200);
 	}
 	fgColor = viewport->palette().color(viewport->foregroundRole());
 
@@ -800,4 +797,13 @@ void PreviewItemDelegate::setThumbnailDetails(PreviewItemDelegate::ThumbnailDeta
 }
 
 
+void PreviewItemDelegate::slotRowsChanged() {
+	// We need to update hover ui because the current index may have
+	// disappeared: for example if the current image is removed with "del".
+	QPoint pos = d->mView->viewport()->mapFromGlobal(QCursor::pos());
+	QModelIndex index = d->mView->indexAt(pos);
+	d->updateHoverUi(index);
+}
+
+
 } // namespace
