@@ -316,6 +316,13 @@ class OKULAR_EXPORT Document : public QObject
          */
         void setNextDocumentViewport( const DocumentViewport &viewport );
 
+        /**
+         * Sets the next @p namedDestination in the viewport history.
+         *
+         * @since 0.9 (KDE 4.3)
+         */
+        void setNextDocumentDestination( const QString &namedDestination );
+
         /**
          * Sets the zoom for the current document.
          *
@@ -692,7 +699,7 @@ class OKULAR_EXPORT Document : public QObject
         Q_PRIVATE_SLOT( d, void saveDocumentInfo() const )
         Q_PRIVATE_SLOT( d, void slotTimedMemoryCheck() )
         Q_PRIVATE_SLOT( d, void sendGeneratorRequest() )
-        Q_PRIVATE_SLOT( d, void rotationFinished( int page ) )
+        Q_PRIVATE_SLOT( d, void rotationFinished( int page, Okular::Page *okularPage ) )
         Q_PRIVATE_SLOT( d, void fontReadingProgress( int page ) )
         Q_PRIVATE_SLOT( d, void fontReadingGotFont( const Okular::FontInfo& font ) )
         Q_PRIVATE_SLOT( d, void slotGeneratorConfigChanged( const QString& ) )
