@@ -24,6 +24,7 @@
 #include <qsplitter.h>
 #include <qstackedwidget.h>
 
+#include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kmenu.h>
@@ -365,6 +366,8 @@ Sidebar::Sidebar( QWidget *parent )
     mainlay->setMargin( 0 );
     mainlay->setSpacing( 0 );
 
+    setAutoFillBackground( true );
+
     d->list = new SidebarListWidget( this );
     mainlay->addWidget( d->list );
     d->list->setMouseTracking( true );
@@ -380,6 +383,7 @@ Sidebar::Sidebar( QWidget *parent )
     d->list->setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     d->list->setContextMenuPolicy( Qt::CustomContextMenu );
     d->list->viewport()->setAutoFillBackground( false );
+    d->list->setFont( KGlobalSettings::toolBarFont() );
 
     d->splitter = new QSplitter( this );
     mainlay->addWidget( d->splitter );
